Class: PlatformAPI::Account

Inherits:
Object
  • Object
show all
Defined in:
lib/platform-api/client.rb

Overview

An account represents an individual signed up to use the Heroku platform.

Instance Method Summary collapse

Constructor Details

#initialize(client) ⇒ Account

Returns a new instance of Account.



1658
1659
1660
# File 'lib/platform-api/client.rb', line 1658

def initialize(client)
  @client = client
end

Instance Method Details

#change_email(account_email_or_account_id, body) ⇒ Object

Change Email for account.

Parameters:

  • account_email_or_account_id:

    unique email address of account or unique identifier of an account

  • body:

    the object to pass as the request payload



1681
1682
1683
# File 'lib/platform-api/client.rb', line 1681

def change_email(, body)
  @client..change_email(, body)
end

#change_password(account_email_or_account_id, body) ⇒ Object

Change Password for account.

Parameters:

  • account_email_or_account_id:

    unique email address of account or unique identifier of an account

  • body:

    the object to pass as the request payload



1689
1690
1691
# File 'lib/platform-api/client.rb', line 1689

def change_password(, body)
  @client..change_password(, body)
end

#delete(account_email_or_account_id) ⇒ Object

Delete account. Note that this action cannot be undone.

Parameters:

  • account_email_or_account_id:

    unique email address of account or unique identifier of an account



1696
1697
1698
# File 'lib/platform-api/client.rb', line 1696

def delete()
  @client..delete()
end

#info(account_email_or_account_id) ⇒ Object

Info for account.

Parameters:

  • account_email_or_account_id:

    unique email address of account or unique identifier of an account



1665
1666
1667
# File 'lib/platform-api/client.rb', line 1665

def info()
  @client..info()
end

#update(account_email_or_account_id, body) ⇒ Object

Update account.

Parameters:

  • account_email_or_account_id:

    unique email address of account or unique identifier of an account

  • body:

    the object to pass as the request payload



1673
1674
1675
# File 'lib/platform-api/client.rb', line 1673

def update(, body)
  @client..update(, body)
end