Class: PlatformAPI::AddonAttachment

Inherits:
Object
  • Object
show all
Defined in:
lib/platform-api/client.rb

Overview

An add-on attachment represents a connection between an app and an add-on that it has been given access to.

Instance Method Summary collapse

Constructor Details

#initialize(client) ⇒ AddonAttachment

Returns a new instance of AddonAttachment.



420
421
422
# File 'lib/platform-api/client.rb', line 420

def initialize(client)
  @client = client
end

Instance Method Details

#create(body) ⇒ Object

Create a new add-on attachment.

Parameters:

  • body:

    the object to pass as the request payload



427
428
429
# File 'lib/platform-api/client.rb', line 427

def create(body)
  @client.addon_attachment.create(body)
end

#delete(addon_attachment_id) ⇒ Object

Delete an existing add-on attachment.

Parameters:

  • addon_attachment_id:

    unique identifier of this add-on attachment



434
435
436
# File 'lib/platform-api/client.rb', line 434

def delete(addon_attachment_id)
  @client.addon_attachment.delete(addon_attachment_id)
end

#info(addon_attachment_id) ⇒ Object

Info for existing add-on attachment.

Parameters:

  • addon_attachment_id:

    unique identifier of this add-on attachment



441
442
443
# File 'lib/platform-api/client.rb', line 441

def info(addon_attachment_id)
  @client.addon_attachment.info(addon_attachment_id)
end

#info_by_app(app_id_or_app_name, addon_attachment_id_or_addon_attachment_name) ⇒ Object

Info for existing add-on attachment for an app.

Parameters:

  • app_id_or_app_name:

    unique identifier of app or unique name of app

  • addon_attachment_id_or_addon_attachment_name:

    unique identifier of this add-on attachment or unique name for this add-on attachment to this app



468
469
470
# File 'lib/platform-api/client.rb', line 468

def info_by_app(app_id_or_app_name, addon_attachment_id_or_addon_attachment_name)
  @client.addon_attachment.info_by_app(app_id_or_app_name, addon_attachment_id_or_addon_attachment_name)
end

#listObject

List existing add-on attachments.



446
447
448
# File 'lib/platform-api/client.rb', line 446

def list()
  @client.addon_attachment.list()
end

#list_by_add_on(addon_id_or_addon_name) ⇒ Object

List existing add-on attachments for an add-on.

Parameters:

  • addon_id_or_addon_name:

    unique identifier of add-on or globally unique name of the add-on



453
454
455
# File 'lib/platform-api/client.rb', line 453

def list_by_add_on(addon_id_or_addon_name)
  @client.addon_attachment.list_by_add_on(addon_id_or_addon_name)
end

#list_by_app(app_id_or_app_name) ⇒ Object

List existing add-on attachments for an app.

Parameters:

  • app_id_or_app_name:

    unique identifier of app or unique name of app



460
461
462
# File 'lib/platform-api/client.rb', line 460

def list_by_app(app_id_or_app_name)
  @client.addon_attachment.list_by_app(app_id_or_app_name)
end