Class: PlatformAPI::AppFeature
- Inherits:
-
Object
- Object
- PlatformAPI::AppFeature
- Defined in:
- lib/platform-api/client.rb
Overview
An app feature represents a Heroku labs capability that can be enabled or disabled for an app on Heroku.
Instance Method Summary collapse
- #info(app_id_or_app_name, app_feature_id_or_app_feature_name) ⇒ Object
-
#initialize(client) ⇒ AppFeature
constructor
A new instance of AppFeature.
- #list(app_id_or_app_name) ⇒ Object
- #update(app_id_or_app_name, app_feature_id_or_app_feature_name, body = {}) ⇒ Object
Constructor Details
#initialize(client) ⇒ AppFeature
Returns a new instance of AppFeature.
1618 1619 1620 |
# File 'lib/platform-api/client.rb', line 1618 def initialize(client) @client = client end |
Instance Method Details
#info(app_id_or_app_name, app_feature_id_or_app_feature_name) ⇒ Object
1632 1633 1634 |
# File 'lib/platform-api/client.rb', line 1632 def info(app_id_or_app_name, app_feature_id_or_app_feature_name) @client.app_feature.info(app_id_or_app_name, app_feature_id_or_app_feature_name) end |
#list(app_id_or_app_name) ⇒ Object
1644 1645 1646 |
# File 'lib/platform-api/client.rb', line 1644 def list(app_id_or_app_name) @client.app_feature.list(app_id_or_app_name) end |
#update(app_id_or_app_name, app_feature_id_or_app_feature_name, body = {}) ⇒ Object
1660 1661 1662 |
# File 'lib/platform-api/client.rb', line 1660 def update(app_id_or_app_name, app_feature_id_or_app_feature_name, body = {}) @client.app_feature.update(app_id_or_app_name, app_feature_id_or_app_feature_name, body) end |