Class: PlatformAPI::AppSetup

Inherits:
Object
  • Object
show all
Defined in:
lib/platform-api/client.rb

Overview

An app setup represents an app on Heroku that is setup using an environment, addons, and scripts described in an app.json manifest file.

Instance Method Summary collapse

Constructor Details

#initialize(client) ⇒ AppSetup

Returns a new instance of AppSetup.



1669
1670
1671
# File 'lib/platform-api/client.rb', line 1669

def initialize(client)
  @client = client
end

Instance Method Details

#create(body = {}) ⇒ Object



1681
1682
1683
# File 'lib/platform-api/client.rb', line 1681

def create(body = {})
  @client.app_setup.create(body)
end

#info(app_setup_id) ⇒ Object



1693
1694
1695
# File 'lib/platform-api/client.rb', line 1693

def info(app_setup_id)
  @client.app_setup.info(app_setup_id)
end