Class: PlatformAPI::BuildpackInstallation

Inherits:
Object
  • Object
show all
Defined in:
lib/platform-api/client.rb

Overview

An buildpack installtion represents a buildpack that will be run against an app.

Instance Method Summary collapse

Constructor Details

#initialize(client) ⇒ BuildpackInstallation

Returns a new instance of BuildpackInstallation.



724
725
726
# File 'lib/platform-api/client.rb', line 724

def initialize(client)
  @client = client
end

Instance Method Details

#list(app_id_or_app_name) ⇒ Object

List an app's existing buildpack installations.

Parameters:

  • app_id_or_app_name:

    unique identifier of app or unique name of app



739
740
741
# File 'lib/platform-api/client.rb', line 739

def list(app_id_or_app_name)
  @client.buildpack_installation.list(app_id_or_app_name)
end

#update(app_id_or_app_name, body) ⇒ Object

Update an app's buildpack installations.

Parameters:

  • app_id_or_app_name:

    unique identifier of app or unique name of app

  • body:

    the object to pass as the request payload



732
733
734
# File 'lib/platform-api/client.rb', line 732

def update(app_id_or_app_name, body)
  @client.buildpack_installation.update(app_id_or_app_name, body)
end