Class: PlatformAPI::Client

Inherits:
Object
  • Object
show all
Defined in:
lib/platform-api/client.rb

Overview

The platform API empowers developers to automate, extend and combine Heroku with other services.

Instance Method Summary collapse

Constructor Details

#initialize(client) ⇒ Client

Returns a new instance of Client.



97
98
99
# File 'lib/platform-api/client.rb', line 97

def initialize(client)
  @client = client
end

Instance Method Details

#accountAccount

An account represents an individual signed up to use the Heroku platform.

Returns:



121
122
123
# File 'lib/platform-api/client.rb', line 121

def 
  @account_resource ||= Account.new(@client)
end

#account_delinquencyAccountDelinquency

A Heroku account becomes delinquent due to non-payment. We suspend and delete delinquent accounts if their invoices remain unpaid.

Returns:



105
106
107
# File 'lib/platform-api/client.rb', line 105

def 
  @account_delinquency_resource ||= AccountDelinquency.new(@client)
end

#account_featureAccountFeature

An account feature represents a Heroku labs capability that can be enabled or disabled for an account on Heroku.

Returns:



113
114
115
# File 'lib/platform-api/client.rb', line 113

def 
  @account_feature_resource ||= AccountFeature.new(@client)
end

#addonAddon

Add-ons represent add-ons that have been provisioned and attached to one or more apps.

Returns:



201
202
203
# File 'lib/platform-api/client.rb', line 201

def addon
  @addon_resource ||= Addon.new(@client)
end

#addon_actionAddonAction

Add-on Actions are lifecycle operations for add-on provisioning and deprovisioning. They allow add-on providers to (de)provision add-ons in the background and then report back when (de)provisioning is complete.

Returns:



129
130
131
# File 'lib/platform-api/client.rb', line 129

def addon_action
  @addon_action_resource ||= AddonAction.new(@client)
end

#addon_attachmentAddonAttachment

An add-on attachment represents a connection between an app and an add-on that it has been given access to.

Returns:



137
138
139
# File 'lib/platform-api/client.rb', line 137

def addon_attachment
  @addon_attachment_resource ||= AddonAttachment.new(@client)
end

#addon_configAddonConfig

Configuration of an Add-on

Returns:



145
146
147
# File 'lib/platform-api/client.rb', line 145

def addon_config
  @addon_config_resource ||= AddonConfig.new(@client)
end

#addon_plan_actionAddonPlanAction

Add-on Plan Actions are Provider functionality for specific add-on installations

Returns:



153
154
155
# File 'lib/platform-api/client.rb', line 153

def addon_plan_action
  @addon_plan_action_resource ||= AddonPlanAction.new(@client)
end

#addon_region_capabilityAddonRegionCapability

Add-on region capabilities represent the relationship between an Add-on Service and a specific Region. Only Beta and GA add-ons are returned by these endpoints.



161
162
163
# File 'lib/platform-api/client.rb', line 161

def addon_region_capability
  @addon_region_capability_resource ||= AddonRegionCapability.new(@client)
end

#addon_serviceAddonService

Add-on services represent add-ons that may be provisioned for apps. Endpoints under add-on services can be accessed without authentication.

Returns:



169
170
171
# File 'lib/platform-api/client.rb', line 169

def addon_service
  @addon_service_resource ||= AddonService.new(@client)
end

#addon_webhookAddonWebhook

Represents the details of a webhook subscription

Returns:



193
194
195
# File 'lib/platform-api/client.rb', line 193

def addon_webhook
  @addon_webhook_resource ||= AddonWebhook.new(@client)
end

#addon_webhook_deliveryAddonWebhookDelivery

Represents the delivery of a webhook notification, including its current status.



177
178
179
# File 'lib/platform-api/client.rb', line 177

def addon_webhook_delivery
  @addon_webhook_delivery_resource ||= AddonWebhookDelivery.new(@client)
end

#addon_webhook_eventAddonWebhookEvent

Represents a webhook event that occurred.

Returns:



185
186
187
# File 'lib/platform-api/client.rb', line 185

def addon_webhook_event
  @addon_webhook_event_resource ||= AddonWebhookEvent.new(@client)
end

#allowed_addon_serviceAllowedAddonService

Entities that have been allowed to be used by a Team

Returns:



209
210
211
# File 'lib/platform-api/client.rb', line 209

def allowed_addon_service
  @allowed_addon_service_resource ||= AllowedAddonService.new(@client)
end

#appApp

An app represents the program that you would like to deploy and run on Heroku.

Returns:



265
266
267
# File 'lib/platform-api/client.rb', line 265

def app
  @app_resource ||= App.new(@client)
end

#app_featureAppFeature

An app feature represents a Heroku labs capability that can be enabled or disabled for an app on Heroku.

Returns:



217
218
219
# File 'lib/platform-api/client.rb', line 217

def app_feature
  @app_feature_resource ||= AppFeature.new(@client)
end

#app_setupAppSetup

An app setup represents an app on Heroku that is setup using an environment, addons, and scripts described in an app.json manifest file.

Returns:



225
226
227
# File 'lib/platform-api/client.rb', line 225

def app_setup
  @app_setup_resource ||= AppSetup.new(@client)
end

#app_transferAppTransfer

An app transfer represents a two party interaction for transferring ownership of an app.

Returns:



233
234
235
# File 'lib/platform-api/client.rb', line 233

def app_transfer
  @app_transfer_resource ||= AppTransfer.new(@client)
end

#app_webhookAppWebhook

Represents the details of a webhook subscription

Returns:



257
258
259
# File 'lib/platform-api/client.rb', line 257

def app_webhook
  @app_webhook_resource ||= AppWebhook.new(@client)
end

#app_webhook_deliveryAppWebhookDelivery

Represents the delivery of a webhook notification, including its current status.

Returns:



241
242
243
# File 'lib/platform-api/client.rb', line 241

def app_webhook_delivery
  @app_webhook_delivery_resource ||= AppWebhookDelivery.new(@client)
end

#app_webhook_eventAppWebhookEvent

Represents a webhook event that occurred.

Returns:



249
250
251
# File 'lib/platform-api/client.rb', line 249

def app_webhook_event
  @app_webhook_event_resource ||= AppWebhookEvent.new(@client)
end

#archiveArchive

An audit trail archive represents a monthly json zipped file containing events

Returns:



273
274
275
# File 'lib/platform-api/client.rb', line 273

def archive
  @archive_resource ||= Archive.new(@client)
end

#audit_trail_eventAuditTrailEvent

An audit trail event represents some action on the platform

Returns:



281
282
283
# File 'lib/platform-api/client.rb', line 281

def audit_trail_event
  @audit_trail_event_resource ||= AuditTrailEvent.new(@client)
end

#buildBuild

A build represents the process of transforming a code tarball into build artifacts

Returns:



289
290
291
# File 'lib/platform-api/client.rb', line 289

def build
  @build_resource ||= Build.new(@client)
end

#buildpack_installationBuildpackInstallation

A buildpack installation represents a buildpack that will be run against an app.



297
298
299
# File 'lib/platform-api/client.rb', line 297

def buildpack_installation
  @buildpack_installation_resource ||= BuildpackInstallation.new(@client)
end

#collaboratorCollaborator

A collaborator represents an account that has been given access to an app on Heroku.

Returns:



305
306
307
# File 'lib/platform-api/client.rb', line 305

def collaborator
  @collaborator_resource ||= Collaborator.new(@client)
end

#config_varConfigVar

Config Vars allow you to manage the configuration information provided to an app on Heroku.

Returns:



313
314
315
# File 'lib/platform-api/client.rb', line 313

def config_var
  @config_var_resource ||= ConfigVar.new(@client)
end

#creditCredit

A credit represents value that will be used up before further charges are assigned to an account.

Returns:



321
322
323
# File 'lib/platform-api/client.rb', line 321

def credit
  @credit_resource ||= Credit.new(@client)
end

#domainDomain

Domains define what web routes should be routed to an app on Heroku.

Returns:



329
330
331
# File 'lib/platform-api/client.rb', line 329

def domain
  @domain_resource ||= Domain.new(@client)
end

#dynoDyno

Dynos encapsulate running processes of an app on Heroku. Detailed information about dyno sizes can be found at: https://devcenter.heroku.com/articles/dyno-types.

Returns:



345
346
347
# File 'lib/platform-api/client.rb', line 345

def dyno
  @dyno_resource ||= Dyno.new(@client)
end

#dyno_sizeDynoSize

Dyno sizes are the values and details of sizes that can be assigned to dynos. This information can also be found at : https://devcenter.heroku.com/articles/dyno-types.

Returns:



337
338
339
# File 'lib/platform-api/client.rb', line 337

def dyno_size
  @dyno_size_resource ||= DynoSize.new(@client)
end

#enterprise_accountEnterpriseAccount

Enterprise accounts allow companies to manage their development teams and billing.

Returns:



377
378
379
# File 'lib/platform-api/client.rb', line 377

def 
  @enterprise_account_resource ||= EnterpriseAccount.new(@client)
end

#enterprise_account_daily_usageEnterpriseAccountDailyUsage

Usage for an enterprise account at a daily resolution.



353
354
355
# File 'lib/platform-api/client.rb', line 353

def 
  @enterprise_account_daily_usage_resource ||= EnterpriseAccountDailyUsage.new(@client)
end

#enterprise_account_memberEnterpriseAccountMember

Enterprise account members are users with access to an enterprise account.



361
362
363
# File 'lib/platform-api/client.rb', line 361

def 
  @enterprise_account_member_resource ||= EnterpriseAccountMember.new(@client)
end

#enterprise_account_monthly_usageEnterpriseAccountMonthlyUsage

Usage for an enterprise account at a monthly resolution.



369
370
371
# File 'lib/platform-api/client.rb', line 369

def 
  @enterprise_account_monthly_usage_resource ||= EnterpriseAccountMonthlyUsage.new(@client)
end

#filter_appsFilterApps

Filters are special endpoints to allow for API consumers to specify a subset of resources to consume in order to reduce the number of requests that are performed. Each filter endpoint endpoint is responsible for determining its supported request format. The endpoints are over POST in order to handle large request bodies without hitting request uri query length limitations, but the requests themselves are idempotent and will not have side effects.

Returns:



385
386
387
# File 'lib/platform-api/client.rb', line 385

def filter_apps
  @filter_apps_resource ||= FilterApps.new(@client)
end

#formationFormation

The formation of processes that should be maintained for an app. Update the formation to scale processes or change dyno sizes. Available process type names and commands are defined by the process_types attribute for the slug currently released on an app.

Returns:



393
394
395
# File 'lib/platform-api/client.rb', line 393

def formation
  @formation_resource ||= Formation.new(@client)
end

#generationGeneration

A generation represents a version of the Heroku platform that includes the app execution environment, routing, telemetry, and build systems.

Returns:



401
402
403
# File 'lib/platform-api/client.rb', line 401

def generation
  @generation_resource ||= Generation.new(@client)
end

#identity_providerIdentityProvider

Identity Providers represent the SAML configuration of teams or an Enterprise account

Returns:



409
410
411
# File 'lib/platform-api/client.rb', line 409

def identity_provider
  @identity_provider_resource ||= IdentityProvider.new(@client)
end

#inbound_rulesetInboundRuleset

An inbound-ruleset is a collection of rules that specify what hosts can or cannot connect to an application.

Returns:



417
418
419
# File 'lib/platform-api/client.rb', line 417

def inbound_ruleset
  @inbound_ruleset_resource ||= InboundRuleset.new(@client)
end

#invoiceInvoice

An invoice is an itemized bill of goods for an account which includes pricing and charges.

Returns:



433
434
435
# File 'lib/platform-api/client.rb', line 433

def invoice
  @invoice_resource ||= Invoice.new(@client)
end

#invoice_addressInvoiceAddress

An invoice address represents the address that should be listed on an invoice.

Returns:



425
426
427
# File 'lib/platform-api/client.rb', line 425

def invoice_address
  @invoice_address_resource ||= InvoiceAddress.new(@client)
end

#keyKey

Keys represent public SSH keys associated with an account and are used to authorize accounts as they are performing git operations.

Returns:



441
442
443
# File 'lib/platform-api/client.rb', line 441

def key
  @key_resource ||= Key.new(@client)
end

#log_drainLogDrain

Log drains provide a way to forward your Heroku logs to an external syslog server for long-term archiving. This external service must be configured to receive syslog packets from Heroku, whereupon its URL can be added to an app using this API. Some add-ons will add a log drain when they are provisioned to an app. These drains can only be removed by removing the add-on.

Returns:



449
450
451
# File 'lib/platform-api/client.rb', line 449

def log_drain
  @log_drain_resource ||= LogDrain.new(@client)
end

#log_sessionLogSession

A log session is a reference to the http based log stream for an app.

Returns:



457
458
459
# File 'lib/platform-api/client.rb', line 457

def log_session
  @log_session_resource ||= LogSession.new(@client)
end

#oauth_authorizationOauthAuthorization

OAuth authorizations represent clients that a Heroku user has authorized to automate, customize or extend their usage of the platform. For more information please refer to the Heroku OAuth documentation

Returns:



465
466
467
# File 'lib/platform-api/client.rb', line 465

def oauth_authorization
  @oauth_authorization_resource ||= OauthAuthorization.new(@client)
end

#oauth_clientOauthClient

OAuth clients are applications that Heroku users can authorize to automate, customize or extend their usage of the platform. For more information please refer to the Heroku OAuth documentation.

Returns:



473
474
475
# File 'lib/platform-api/client.rb', line 473

def oauth_client
  @oauth_client_resource ||= OauthClient.new(@client)
end

#oauth_grantOauthGrant

OAuth grants are used to obtain authorizations on behalf of a user. For more information please refer to the Heroku OAuth documentation

Returns:



481
482
483
# File 'lib/platform-api/client.rb', line 481

def oauth_grant
  @oauth_grant_resource ||= OauthGrant.new(@client)
end

#oauth_tokenOauthToken

OAuth tokens provide access for authorized clients to act on behalf of a Heroku user to automate, customize or extend their usage of the platform. For more information please refer to the Heroku OAuth documentation

Returns:



489
490
491
# File 'lib/platform-api/client.rb', line 489

def oauth_token
  @oauth_token_resource ||= OauthToken.new(@client)
end

#oci_imageOciImage

An OCI (Open Container Initiative) image is a standardized format for packaging and distributing containerized applications, ready to run on the platform.

Returns:



497
498
499
# File 'lib/platform-api/client.rb', line 497

def oci_image
  @oci_image_resource ||= OciImage.new(@client)
end

#password_resetPasswordReset

A password reset represents a in-process password reset attempt.

Returns:



505
506
507
# File 'lib/platform-api/client.rb', line 505

def password_reset
  @password_reset_resource ||= PasswordReset.new(@client)
end

#peeringPeering

Peering provides a way to peer your Private Space VPC to another AWS VPC.

Returns:



521
522
523
# File 'lib/platform-api/client.rb', line 521

def peering
  @peering_resource ||= Peering.new(@client)
end

#peering_infoPeeringInfo

Peering Info gives you the information necessary to peer an AWS VPC to a Private Space.

Returns:



513
514
515
# File 'lib/platform-api/client.rb', line 513

def peering_info
  @peering_info_resource ||= PeeringInfo.new(@client)
end

#permission_entityPermissionEntity

An owned entity including users' permissions.

Returns:



529
530
531
# File 'lib/platform-api/client.rb', line 529

def permission_entity
  @permission_entity_resource ||= PermissionEntity.new(@client)
end

#pipelinePipeline

A pipeline allows grouping of apps into different stages.

Returns:



609
610
611
# File 'lib/platform-api/client.rb', line 609

def pipeline
  @pipeline_resource ||= Pipeline.new(@client)
end

#pipeline_buildPipelineBuild

Information about the latest builds of apps in a pipeline. A build represents the process of transforming code into build artifacts.

Returns:



537
538
539
# File 'lib/platform-api/client.rb', line 537

def pipeline_build
  @pipeline_build_resource ||= PipelineBuild.new(@client)
end

#pipeline_config_varPipelineConfigVar

Pipeline config vars in Heroku CI and review apps used to manage the configuration information for a pipeline.

Returns:



545
546
547
# File 'lib/platform-api/client.rb', line 545

def pipeline_config_var
  @pipeline_config_var_resource ||= PipelineConfigVar.new(@client)
end

#pipeline_couplingPipelineCoupling

Information about an app's coupling to a pipeline

Returns:



553
554
555
# File 'lib/platform-api/client.rb', line 553

def pipeline_coupling
  @pipeline_coupling_resource ||= PipelineCoupling.new(@client)
end

#pipeline_deploymentPipelineDeployment

Information about the latest deployment of each app in a pipeline. A deployment is the process of moving the build artifacts to a target environment.

Returns:



561
562
563
# File 'lib/platform-api/client.rb', line 561

def pipeline_deployment
  @pipeline_deployment_resource ||= PipelineDeployment.new(@client)
end

#pipeline_promotionPipelinePromotion

Promotions allow you to move code from an app in a pipeline to all targets

Returns:



577
578
579
# File 'lib/platform-api/client.rb', line 577

def pipeline_promotion
  @pipeline_promotion_resource ||= PipelinePromotion.new(@client)
end

#pipeline_promotion_targetPipelinePromotionTarget

Promotion targets represent an individual app being promoted to



569
570
571
# File 'lib/platform-api/client.rb', line 569

def pipeline_promotion_target
  @pipeline_promotion_target_resource ||= PipelinePromotionTarget.new(@client)
end

#pipeline_releasePipelineRelease

Information about the latest release of each app in a pipeline. A release makes a deployment available to end-users.

Returns:



585
586
587
# File 'lib/platform-api/client.rb', line 585

def pipeline_release
  @pipeline_release_resource ||= PipelineRelease.new(@client)
end

#pipeline_stackPipelineStack

A pipeline's stack is determined by the apps in the pipeline. This is used during creation of CI and Review Apps that have no stack defined in app.json

Returns:



593
594
595
# File 'lib/platform-api/client.rb', line 593

def pipeline_stack
  @pipeline_stack_resource ||= PipelineStack.new(@client)
end

#pipeline_transferPipelineTransfer

A pipeline transfer is the process of changing pipeline ownership along with the contained apps.

Returns:



601
602
603
# File 'lib/platform-api/client.rb', line 601

def pipeline_transfer
  @pipeline_transfer_resource ||= PipelineTransfer.new(@client)
end

#planPlan

Plans represent different configurations of add-ons that may be added to apps. Endpoints under add-on services can be accessed without authentication.

Returns:



617
618
619
# File 'lib/platform-api/client.rb', line 617

def plan
  @plan_resource ||= Plan.new(@client)
end

#rate_limitRateLimit

Rate Limit represents the number of request tokens each account holds. Requests to this endpoint do not count towards the rate limit.

Returns:



625
626
627
# File 'lib/platform-api/client.rb', line 625

def rate_limit
  @rate_limit_resource ||= RateLimit.new(@client)
end

#regionRegion

A region represents a geographic location in which your application may run.

Returns:



633
634
635
# File 'lib/platform-api/client.rb', line 633

def region
  @region_resource ||= Region.new(@client)
end

#releaseRelease

A release represents a combination of code, config vars and add-ons for an app on Heroku.

Returns:



641
642
643
# File 'lib/platform-api/client.rb', line 641

def release
  @release_resource ||= Release.new(@client)
end

#review_appReviewApp

An ephemeral app to review a set of changes

Returns:



649
650
651
# File 'lib/platform-api/client.rb', line 649

def review_app
  @review_app_resource ||= ReviewApp.new(@client)
end

#review_app_configReviewAppConfig

Review apps can be configured for pipelines.

Returns:



657
658
659
# File 'lib/platform-api/client.rb', line 657

def review_app_config
  @review_app_config_resource ||= ReviewAppConfig.new(@client)
end

#slugSlug

A slug is a snapshot of your application code that is ready to run on the platform.

Returns:



665
666
667
# File 'lib/platform-api/client.rb', line 665

def slug
  @slug_resource ||= Slug.new(@client)
end

#sms_numberSmsNumber

SMS numbers are used for recovery on accounts with two-factor authentication enabled.

Returns:



673
674
675
# File 'lib/platform-api/client.rb', line 673

def sms_number
  @sms_number_resource ||= SmsNumber.new(@client)
end

#sni_endpointSniEndpoint

SNI Endpoint is a public address serving a custom SSL cert for HTTPS traffic, using the SNI TLS extension, to a Heroku app.

Returns:



681
682
683
# File 'lib/platform-api/client.rb', line 681

def sni_endpoint
  @sni_endpoint_resource ||= SniEndpoint.new(@client)
end

#sourceSource

A source is a location for uploading and downloading an application's source code.

Returns:



689
690
691
# File 'lib/platform-api/client.rb', line 689

def source
  @source_resource ||= Source.new(@client)
end

#spaceSpace

A space is an isolated, highly available, secure app execution environment.

Returns:



729
730
731
# File 'lib/platform-api/client.rb', line 729

def space
  @space_resource ||= Space.new(@client)
end

#space_app_accessSpaceAppAccess

Space access represents the permissions a particular user has on a particular space.

Returns:



697
698
699
# File 'lib/platform-api/client.rb', line 697

def space_app_access
  @space_app_access_resource ||= SpaceAppAccess.new(@client)
end

#space_natSpaceNat

Network address translation (NAT) for stable outbound IP addresses from a space

Returns:



705
706
707
# File 'lib/platform-api/client.rb', line 705

def space_nat
  @space_nat_resource ||= SpaceNat.new(@client)
end

#space_topologySpaceTopology

Space Topology provides you with a mechanism for viewing all the running dynos, formations and applications for a space. This is the same data thats used to power our DNS Service Discovery.

Returns:



713
714
715
# File 'lib/platform-api/client.rb', line 713

def space_topology
  @space_topology_resource ||= SpaceTopology.new(@client)
end

#space_transferSpaceTransfer

Transfer spaces between enterprise teams with the same Enterprise Account.

Returns:



721
722
723
# File 'lib/platform-api/client.rb', line 721

def space_transfer
  @space_transfer_resource ||= SpaceTransfer.new(@client)
end

#stackStack

Stacks are the different application execution environments available in the Heroku platform.

Returns:



737
738
739
# File 'lib/platform-api/client.rb', line 737

def stack
  @stack_resource ||= Stack.new(@client)
end

#teamTeam

Teams allow you to manage access to a shared group of applications and other resources.

Returns:



849
850
851
# File 'lib/platform-api/client.rb', line 849

def team
  @team_resource ||= Team.new(@client)
end

#team_addonTeamAddon

Returns:



745
746
747
# File 'lib/platform-api/client.rb', line 745

def team_addon
  @team_addon_resource ||= TeamAddon.new(@client)
end

#team_appTeamApp

A team app encapsulates the team specific functionality of Heroku apps.

Returns:



769
770
771
# File 'lib/platform-api/client.rb', line 769

def team_app
  @team_app_resource ||= TeamApp.new(@client)
end

#team_app_collaboratorTeamAppCollaborator

A team collaborator represents an account that has been given access to a team app on Heroku.

Returns:



753
754
755
# File 'lib/platform-api/client.rb', line 753

def team_app_collaborator
  @team_app_collaborator_resource ||= TeamAppCollaborator.new(@client)
end

#team_app_permissionTeamAppPermission

A team app permission is a behavior that is assigned to a user in a team app.

Returns:



761
762
763
# File 'lib/platform-api/client.rb', line 761

def team_app_permission
  @team_app_permission_resource ||= TeamAppPermission.new(@client)
end

#team_daily_usageTeamDailyUsage

Usage for an enterprise team at a daily resolution.

Returns:



777
778
779
# File 'lib/platform-api/client.rb', line 777

def team_daily_usage
  @team_daily_usage_resource ||= TeamDailyUsage.new(@client)
end

#team_delinquencyTeamDelinquency

A Heroku team becomes delinquent due to non-payment. We suspend and delete delinquent teams if their invoices remain unpaid.

Returns:



785
786
787
# File 'lib/platform-api/client.rb', line 785

def team_delinquency
  @team_delinquency_resource ||= TeamDelinquency.new(@client)
end

#team_featureTeamFeature

A team feature represents a feature enabled on a team account.

Returns:



793
794
795
# File 'lib/platform-api/client.rb', line 793

def team_feature
  @team_feature_resource ||= TeamFeature.new(@client)
end

#team_invitationTeamInvitation

A team invitation represents an invite to a team.

Returns:



801
802
803
# File 'lib/platform-api/client.rb', line 801

def team_invitation
  @team_invitation_resource ||= TeamInvitation.new(@client)
end

#team_invoiceTeamInvoice

A Team Invoice is an itemized bill of goods for a team which includes pricing and charges.

Returns:



809
810
811
# File 'lib/platform-api/client.rb', line 809

def team_invoice
  @team_invoice_resource ||= TeamInvoice.new(@client)
end

#team_memberTeamMember

A team member is an individual with access to a team.

Returns:



817
818
819
# File 'lib/platform-api/client.rb', line 817

def team_member
  @team_member_resource ||= TeamMember.new(@client)
end

#team_monthly_usageTeamMonthlyUsage

Usage for an enterprise team at a monthly resolution.

Returns:



825
826
827
# File 'lib/platform-api/client.rb', line 825

def team_monthly_usage
  @team_monthly_usage_resource ||= TeamMonthlyUsage.new(@client)
end

#team_preferencesTeamPreferences

Tracks a Team's Preferences

Returns:



833
834
835
# File 'lib/platform-api/client.rb', line 833

def team_preferences
  @team_preferences_resource ||= TeamPreferences.new(@client)
end

#team_spaceTeamSpace

A space is an isolated, highly available, secure app execution environment.

Returns:



841
842
843
# File 'lib/platform-api/client.rb', line 841

def team_space
  @team_space_resource ||= TeamSpace.new(@client)
end

#telemetry_drainTelemetryDrain

A telemetry drain forwards OpenTelemetry traces, metrics, and logs to your own consumer. For Fir-generation apps only.

Returns:



857
858
859
# File 'lib/platform-api/client.rb', line 857

def telemetry_drain
  @telemetry_drain_resource ||= TelemetryDrain.new(@client)
end

#test_caseTestCase

A single test case belonging to a test run

Returns:



865
866
867
# File 'lib/platform-api/client.rb', line 865

def test_case
  @test_case_resource ||= TestCase.new(@client)
end

#test_nodeTestNode

A single test node belonging to a test run

Returns:



873
874
875
# File 'lib/platform-api/client.rb', line 873

def test_node
  @test_node_resource ||= TestNode.new(@client)
end

#test_runTestRun

An execution or trial of one or more tests

Returns:



881
882
883
# File 'lib/platform-api/client.rb', line 881

def test_run
  @test_run_resource ||= TestRun.new(@client)
end

#user_preferencesUserPreferences

Tracks a user's preferences and message dismissals

Returns:



889
890
891
# File 'lib/platform-api/client.rb', line 889

def user_preferences
  @user_preferences_resource ||= UserPreferences.new(@client)
end

#vpn_connectionVpnConnection

VPN provides a way to connect your Private Spaces to your network via VPN.

Returns:



897
898
899
# File 'lib/platform-api/client.rb', line 897

def vpn_connection
  @vpn_connection_resource ||= VpnConnection.new(@client)
end