Method: PlatformAPI::Client#key

Defined in:
lib/platform-api/client.rb

#keyKey

Keys represent public SSH keys associated with an account and are used to authorize accounts as they are performing git operations.

Returns:



327
328
329
# File 'lib/platform-api/client.rb', line 327

def key
  @key_resource ||= Key.new(@client)
end