Class: PlatformAPI::ConfigVar

Inherits:
Object
  • Object
show all
Defined in:
lib/platform-api/client.rb

Overview

Config Vars allow you to manage the configuration information provided to an app on Heroku.

Instance Method Summary collapse

Constructor Details

#initialize(client) ⇒ ConfigVar



1644
1645
1646
# File 'lib/platform-api/client.rb', line 1644

def initialize(client)
  @client = client
end

Instance Method Details

#info_for_app(app_id_or_app_name) ⇒ Object

Get config-vars for app.



1651
1652
1653
# File 'lib/platform-api/client.rb', line 1651

def info_for_app(app_id_or_app_name)
  @client.config_var.info_for_app(app_id_or_app_name)
end

#info_for_app_release(app_id_or_app_name, release_id_or_release_version) ⇒ Object

Get config-vars for a release.



1659
1660
1661
# File 'lib/platform-api/client.rb', line 1659

def info_for_app_release(app_id_or_app_name, release_id_or_release_version)
  @client.config_var.info_for_app_release(app_id_or_app_name, release_id_or_release_version)
end

#update(app_id_or_app_name, body = {}) ⇒ Object

Update config-vars for app. You can update existing config-vars by setting them again, and remove by setting it to null.



1667
1668
1669
# File 'lib/platform-api/client.rb', line 1667

def update(app_id_or_app_name, body = {})
  @client.config_var.update(app_id_or_app_name, body)
end