Class: PlatformAPI::EnterpriseAccount

Inherits:
Object
  • Object
show all
Defined in:
lib/platform-api/client.rb

Overview

Enterprise accounts allow companies to manage their development teams and billing.

Instance Method Summary collapse

Constructor Details

#initialize(client) ⇒ EnterpriseAccount

Returns a new instance of EnterpriseAccount.



2700
2701
2702
# File 'lib/platform-api/client.rb', line 2700

def initialize(client)
  @client = client
end

Instance Method Details

#info(enterprise_account_id_or_enterprise_account_name) ⇒ Object



2719
2720
2721
# File 'lib/platform-api/client.rb', line 2719

def info()
  @client..info()
end

#listObject

List enterprise accounts in which you are a member.



2707
2708
2709
# File 'lib/platform-api/client.rb', line 2707

def list()
  @client..list()
end

#update(enterprise_account_id_or_enterprise_account_name, body = {}) ⇒ Object



2733
2734
2735
# File 'lib/platform-api/client.rb', line 2733

def update(, body = {})
  @client..update(, body)
end