Class: PlatformAPI::FilterApps

Inherits:
Object
  • Object
show all
Defined in:
lib/platform-api/client.rb

Overview

Filters are special endpoints to allow for API consumers to specify a subset of resources to consume in order to reduce the number of requests that are performed. Each filter endpoint endpoint is responsible for determining its supported request format. The endpoints are over POST in order to handle large request bodies without hitting request uri query length limitations, but the requests themselves are idempotent and will not have side effects.

Instance Method Summary collapse

Constructor Details

#initialize(client) ⇒ FilterApps

Returns a new instance of FilterApps.



2742
2743
2744
# File 'lib/platform-api/client.rb', line 2742

def initialize(client)
  @client = client
end

Instance Method Details

#apps(body = {}) ⇒ Object



2754
2755
2756
# File 'lib/platform-api/client.rb', line 2754

def apps(body = {})
  @client.filter_apps.apps(body)
end