Class: PlatformAPI::Generation

Inherits:
Object
  • Object
show all
Defined in:
lib/platform-api/client.rb

Overview

A generation represents a version of the Heroku platform that includes the app execution environment, routing, telemetry, and build systems.

Instance Method Summary collapse

Constructor Details

#initialize(client) ⇒ Generation

Returns a new instance of Generation.



2828
2829
2830
# File 'lib/platform-api/client.rb', line 2828

def initialize(client)
  @client = client
end

Instance Method Details

#info(stack_name_or_stack_id) ⇒ Object



2840
2841
2842
# File 'lib/platform-api/client.rb', line 2840

def info(stack_name_or_stack_id)
  @client.generation.info(stack_name_or_stack_id)
end

#listObject

List available generations.



2847
2848
2849
# File 'lib/platform-api/client.rb', line 2847

def list()
  @client.generation.list()
end

#list_by_team(team_name_or_team_id) ⇒ Object



2859
2860
2861
# File 'lib/platform-api/client.rb', line 2859

def list_by_team(team_name_or_team_id)
  @client.generation.list_by_team(team_name_or_team_id)
end