Class: PlatformAPI::InboundRuleset
- Inherits:
-
Object
- Object
- PlatformAPI::InboundRuleset
- Defined in:
- lib/platform-api/client.rb
Overview
An inbound-ruleset is a collection of rules that specify what hosts can or cannot connect to an application.
Instance Method Summary collapse
- #create(space_id_or_space_name, body = {}) ⇒ Object
- #current(space_id_or_space_name) ⇒ Object
- #info(space_id_or_space_name, inbound_ruleset_id) ⇒ Object
-
#initialize(client) ⇒ InboundRuleset
constructor
A new instance of InboundRuleset.
- #list(space_id_or_space_name) ⇒ Object
Constructor Details
#initialize(client) ⇒ InboundRuleset
Returns a new instance of InboundRuleset.
2933 2934 2935 |
# File 'lib/platform-api/client.rb', line 2933 def initialize(client) @client = client end |
Instance Method Details
#create(space_id_or_space_name, body = {}) ⇒ Object
2985 2986 2987 |
# File 'lib/platform-api/client.rb', line 2985 def create(space_id_or_space_name, body = {}) @client.inbound_ruleset.create(space_id_or_space_name, body) end |
#current(space_id_or_space_name) ⇒ Object
2945 2946 2947 |
# File 'lib/platform-api/client.rb', line 2945 def current(space_id_or_space_name) @client.inbound_ruleset.current(space_id_or_space_name) end |
#info(space_id_or_space_name, inbound_ruleset_id) ⇒ Object
2959 2960 2961 |
# File 'lib/platform-api/client.rb', line 2959 def info(space_id_or_space_name, inbound_ruleset_id) @client.inbound_ruleset.info(space_id_or_space_name, inbound_ruleset_id) end |
#list(space_id_or_space_name) ⇒ Object
2971 2972 2973 |
# File 'lib/platform-api/client.rb', line 2971 def list(space_id_or_space_name) @client.inbound_ruleset.list(space_id_or_space_name) end |