Class: PlatformAPI::OauthClient

Inherits:
Object
  • Object
show all
Defined in:
lib/platform-api/client.rb

Overview

OAuth clients are applications that Heroku users can authorize to automate, customize or extend their usage of the platform. For more information please refer to the Heroku OAuth documentation.

Instance Method Summary collapse

Constructor Details

#initialize(client) ⇒ OauthClient

Returns a new instance of OauthClient.



3270
3271
3272
# File 'lib/platform-api/client.rb', line 3270

def initialize(client)
  @client = client
end

Instance Method Details

#create(body = {}) ⇒ Object



3282
3283
3284
# File 'lib/platform-api/client.rb', line 3282

def create(body = {})
  @client.oauth_client.create(body)
end

#delete(oauth_client_id) ⇒ Object



3294
3295
3296
# File 'lib/platform-api/client.rb', line 3294

def delete(oauth_client_id)
  @client.oauth_client.delete(oauth_client_id)
end

#info(oauth_client_id) ⇒ Object



3306
3307
3308
# File 'lib/platform-api/client.rb', line 3306

def info(oauth_client_id)
  @client.oauth_client.info(oauth_client_id)
end

#listObject

List OAuth clients



3313
3314
3315
# File 'lib/platform-api/client.rb', line 3313

def list()
  @client.oauth_client.list()
end

#rotate_credentials(oauth_client_id) ⇒ Object



3339
3340
3341
# File 'lib/platform-api/client.rb', line 3339

def rotate_credentials(oauth_client_id)
  @client.oauth_client.rotate_credentials(oauth_client_id)
end

#update(oauth_client_id, body = {}) ⇒ Object



3327
3328
3329
# File 'lib/platform-api/client.rb', line 3327

def update(oauth_client_id, body = {})
  @client.oauth_client.update(oauth_client_id, body)
end