Class: PlatformAPI::Organization

Inherits:
Object
  • Object
show all
Defined in:
lib/platform-api/client.rb

Overview

Organizations allow you to manage access to a shared group of applications across your development team.

Instance Method Summary collapse

Constructor Details

#initialize(client) ⇒ Organization

Returns a new instance of Organization.



1334
1335
1336
# File 'lib/platform-api/client.rb', line 1334

def initialize(client)
  @client = client
end

Instance Method Details

#info(organization_name) ⇒ Object

Info for an organization.

Parameters:

  • organization_name:

    unique name of organization



1346
1347
1348
# File 'lib/platform-api/client.rb', line 1346

def info(organization_name)
  @client.organization.info(organization_name)
end

#listObject

List organizations in which you are a member.



1339
1340
1341
# File 'lib/platform-api/client.rb', line 1339

def list()
  @client.organization.list()
end

#update(organization_name, body) ⇒ Object

Set or unset the organization as your default organization.

Parameters:

  • organization_name:

    unique name of organization

  • body:

    the object to pass as the request payload



1354
1355
1356
# File 'lib/platform-api/client.rb', line 1354

def update(organization_name, body)
  @client.organization.update(organization_name, body)
end