Class: PlatformAPI::OrganizationApp

Inherits:
Object
  • Object
show all
Defined in:
lib/platform-api/client.rb

Overview

An organization app encapsulates the organization specific functionality of Heroku apps.

Instance Method Summary collapse

Constructor Details

#initialize(client) ⇒ OrganizationApp

Returns a new instance of OrganizationApp.



1225
1226
1227
# File 'lib/platform-api/client.rb', line 1225

def initialize(client)
  @client = client
end

Instance Method Details

#create(body) ⇒ Object

Create a new app in the specified organization, in the default organization if unspecified, or in personal account, if default organization is not set.

Parameters:

  • body:

    the object to pass as the request payload



1232
1233
1234
# File 'lib/platform-api/client.rb', line 1232

def create(body)
  @client.organization_app.create(body)
end

#info(app_name) ⇒ Object

Info for an organization app.

Parameters:

  • app_name:

    unique name of app



1251
1252
1253
# File 'lib/platform-api/client.rb', line 1251

def info(app_name)
  @client.organization_app.info(app_name)
end

#listObject

List apps in the default organization, or in personal account, if default organization is not set.



1237
1238
1239
# File 'lib/platform-api/client.rb', line 1237

def list()
  @client.organization_app.list()
end

#list_for_organization(organization_name) ⇒ Object

List organization apps.

Parameters:

  • organization_name:

    unique name of organization



1244
1245
1246
# File 'lib/platform-api/client.rb', line 1244

def list_for_organization(organization_name)
  @client.organization_app.list_for_organization(organization_name)
end

#transfer_to_account(app_name, body) ⇒ Object

Transfer an existing organization app to another Heroku account.

Parameters:

  • app_name:

    unique name of app

  • body:

    the object to pass as the request payload



1267
1268
1269
# File 'lib/platform-api/client.rb', line 1267

def (app_name, body)
  @client.organization_app.(app_name, body)
end

#transfer_to_organization(app_name, body) ⇒ Object

Transfer an existing organization app to another organization.

Parameters:

  • app_name:

    unique name of app

  • body:

    the object to pass as the request payload



1275
1276
1277
# File 'lib/platform-api/client.rb', line 1275

def transfer_to_organization(app_name, body)
  @client.organization_app.transfer_to_organization(app_name, body)
end

#update_locked(app_name, body) ⇒ Object

Lock or unlock an organization app.

Parameters:

  • app_name:

    unique name of app

  • body:

    the object to pass as the request payload



1259
1260
1261
# File 'lib/platform-api/client.rb', line 1259

def update_locked(app_name, body)
  @client.organization_app.update_locked(app_name, body)
end