Class: PlatformAPI::OrganizationAppCollaborator
- Inherits:
-
Object
- Object
- PlatformAPI::OrganizationAppCollaborator
- Defined in:
- lib/platform-api/client.rb
Overview
An organization collaborator represents an account that has been given access to an organization app on Heroku.
Instance Method Summary collapse
-
#create(app_id_or_app_name, body) ⇒ Object
Create a new collaborator on an organization app.
-
#delete(app_name, collaborator_email) ⇒ Object
Delete an existing collaborator from an organization app.
-
#info(app_name, collaborator_email) ⇒ Object
Info for a collaborator on an organization app.
-
#initialize(client) ⇒ OrganizationAppCollaborator
constructor
A new instance of OrganizationAppCollaborator.
-
#list(app_name) ⇒ Object
List collaborators on an organization app.
Constructor Details
#initialize(client) ⇒ OrganizationAppCollaborator
Returns a new instance of OrganizationAppCollaborator.
1187 1188 1189 |
# File 'lib/platform-api/client.rb', line 1187 def initialize(client) @client = client end |
Instance Method Details
#create(app_id_or_app_name, body) ⇒ Object
Create a new collaborator on an organization app. Use this endpoint instead of the /apps/{app_id_or_name}/collaborator endpoint when you want the collaborator to be granted privileges according to their role in the organization.
1195 1196 1197 |
# File 'lib/platform-api/client.rb', line 1195 def create(app_id_or_app_name, body) @client.organization_app_collaborator.create(app_id_or_app_name, body) end |
#delete(app_name, collaborator_email) ⇒ Object
Delete an existing collaborator from an organization app.
1203 1204 1205 |
# File 'lib/platform-api/client.rb', line 1203 def delete(app_name, collaborator_email) @client.organization_app_collaborator.delete(app_name, collaborator_email) end |
#info(app_name, collaborator_email) ⇒ Object
Info for a collaborator on an organization app.
1211 1212 1213 |
# File 'lib/platform-api/client.rb', line 1211 def info(app_name, collaborator_email) @client.organization_app_collaborator.info(app_name, collaborator_email) end |
#list(app_name) ⇒ Object
List collaborators on an organization app.
1218 1219 1220 |
# File 'lib/platform-api/client.rb', line 1218 def list(app_name) @client.organization_app_collaborator.list(app_name) end |