Class: PlatformAPI::OrganizationMember

Inherits:
Object
  • Object
show all
Defined in:
lib/platform-api/client.rb

Overview

An organization member is an individual with access to an organization.

Instance Method Summary collapse

Constructor Details

#initialize(client) ⇒ OrganizationMember

Returns a new instance of OrganizationMember.



1304
1305
1306
# File 'lib/platform-api/client.rb', line 1304

def initialize(client)
  @client = client
end

Instance Method Details

#create_or_update(organization_name, body) ⇒ Object

Create a new organization member, or update their role.

Parameters:

  • organization_name:

    unique name of organization

  • body:

    the object to pass as the request payload



1312
1313
1314
# File 'lib/platform-api/client.rb', line 1312

def create_or_update(organization_name, body)
  @client.organization_member.create_or_update(organization_name, body)
end

#delete(organization_name, organization_member_email) ⇒ Object

Remove a member from the organization.

Parameters:

  • organization_name:

    unique name of organization

  • organization_member_email:

    email address of the organization member



1320
1321
1322
# File 'lib/platform-api/client.rb', line 1320

def delete(organization_name, organization_member_email)
  @client.organization_member.delete(organization_name, organization_member_email)
end

#list(organization_name) ⇒ Object

List members of the organization.

Parameters:

  • organization_name:

    unique name of organization



1327
1328
1329
# File 'lib/platform-api/client.rb', line 1327

def list(organization_name)
  @client.organization_member.list(organization_name)
end