Class: PlatformAPI::PipelineDeployment

Inherits:
Object
  • Object
show all
Defined in:
lib/platform-api/client.rb

Overview

Information about the latest deployment of each app in a pipeline. A deployment is the process of moving the build artifacts to a target environment.

Instance Method Summary collapse

Constructor Details

#initialize(client) ⇒ PipelineDeployment

Returns a new instance of PipelineDeployment.



3736
3737
3738
# File 'lib/platform-api/client.rb', line 3736

def initialize(client)
  @client = client
end

Instance Method Details

#list(pipeline_id) ⇒ Object



3748
3749
3750
# File 'lib/platform-api/client.rb', line 3748

def list(pipeline_id)
  @client.pipeline_deployment.list(pipeline_id)
end