Class: PlatformAPI::SSLEndpoint

Inherits:
Object
  • Object
show all
Defined in:
lib/platform-api/client.rb

Overview

SSL Endpoint is a public address serving custom SSL cert for HTTPS traffic to a Heroku app. Note that an app must have the ssl:endpoint addon installed before it can provision an SSL Endpoint using these APIs.

Instance Method Summary collapse

Constructor Details

#initialize(client) ⇒ SSLEndpoint

Returns a new instance of SSLEndpoint.



1546
1547
1548
# File 'lib/platform-api/client.rb', line 1546

def initialize(client)
  @client = client
end

Instance Method Details

#create(app_id_or_app_name, body) ⇒ Object

Create a new SSL endpoint.

Parameters:

  • app_id_or_app_name:

    unique identifier of app or unique name of app

  • body:

    the object to pass as the request payload



1554
1555
1556
# File 'lib/platform-api/client.rb', line 1554

def create(app_id_or_app_name, body)
  @client.ssl_endpoint.create(app_id_or_app_name, body)
end

#delete(app_id_or_app_name, ssl_endpoint_id_or_ssl_endpoint_name) ⇒ Object

Delete existing SSL endpoint.

Parameters:

  • app_id_or_app_name:

    unique identifier of app or unique name of app

  • ssl_endpoint_id_or_ssl_endpoint_name:

    unique identifier of this SSL endpoint or unique name for SSL endpoint



1562
1563
1564
# File 'lib/platform-api/client.rb', line 1562

def delete(app_id_or_app_name, ssl_endpoint_id_or_ssl_endpoint_name)
  @client.ssl_endpoint.delete(app_id_or_app_name, ssl_endpoint_id_or_ssl_endpoint_name)
end

#info(app_id_or_app_name, ssl_endpoint_id_or_ssl_endpoint_name) ⇒ Object

Info for existing SSL endpoint.

Parameters:

  • app_id_or_app_name:

    unique identifier of app or unique name of app

  • ssl_endpoint_id_or_ssl_endpoint_name:

    unique identifier of this SSL endpoint or unique name for SSL endpoint



1570
1571
1572
# File 'lib/platform-api/client.rb', line 1570

def info(app_id_or_app_name, ssl_endpoint_id_or_ssl_endpoint_name)
  @client.ssl_endpoint.info(app_id_or_app_name, ssl_endpoint_id_or_ssl_endpoint_name)
end

#list(app_id_or_app_name) ⇒ Object

List existing SSL endpoints.

Parameters:

  • app_id_or_app_name:

    unique identifier of app or unique name of app



1577
1578
1579
# File 'lib/platform-api/client.rb', line 1577

def list(app_id_or_app_name)
  @client.ssl_endpoint.list(app_id_or_app_name)
end

#update(app_id_or_app_name, ssl_endpoint_id_or_ssl_endpoint_name, body) ⇒ Object

Update an existing SSL endpoint.

Parameters:

  • app_id_or_app_name:

    unique identifier of app or unique name of app

  • ssl_endpoint_id_or_ssl_endpoint_name:

    unique identifier of this SSL endpoint or unique name for SSL endpoint

  • body:

    the object to pass as the request payload



1586
1587
1588
# File 'lib/platform-api/client.rb', line 1586

def update(app_id_or_app_name, ssl_endpoint_id_or_ssl_endpoint_name, body)
  @client.ssl_endpoint.update(app_id_or_app_name, ssl_endpoint_id_or_ssl_endpoint_name, body)
end