Class: PlatformAPI::SpaceTopology

Inherits:
Object
  • Object
show all
Defined in:
lib/platform-api/client.rb

Overview

Space Topology provides you with a mechanism for viewing all the running dynos, formations and applications for a space. This is the same data thats used to power our DNS Service Discovery.

Instance Method Summary collapse

Constructor Details

#initialize(client) ⇒ SpaceTopology

Returns a new instance of SpaceTopology.



4485
4486
4487
# File 'lib/platform-api/client.rb', line 4485

def initialize(client)
  @client = client
end

Instance Method Details

#topology(space_id_or_space_name) ⇒ Object



4497
4498
4499
# File 'lib/platform-api/client.rb', line 4497

def topology(space_id_or_space_name)
  @client.space_topology.topology(space_id_or_space_name)
end