Class: PlatformAPI::WhitelistedAddonService

Inherits:
Object
  • Object
show all
Defined in:
lib/platform-api/client.rb

Overview

Entities that have been whitelisted to be used by an Organization

Instance Method Summary collapse

Constructor Details

#initialize(client) ⇒ WhitelistedAddonService

Returns a new instance of WhitelistedAddonService.



3460
3461
3462
# File 'lib/platform-api/client.rb', line 3460

def initialize(client)
  @client = client
end

Instance Method Details

#create_by_organization(organization_name_or_organization_id, body = {}) ⇒ Object

Whitelist an Add-on Service

Parameters:

  • organization_name_or_organization_id:

    unique name of organization or unique identifier of organization

  • body:

    the object to pass as the request payload



3475
3476
3477
# File 'lib/platform-api/client.rb', line 3475

def create_by_organization(organization_name_or_organization_id, body = {})
  @client.whitelisted_addon_service.create_by_organization(organization_name_or_organization_id, body)
end

#create_by_team(team_name_or_team_id, body = {}) ⇒ Object

Whitelist an Add-on Service

Parameters:

  • team_name_or_team_id:

    unique name of team or unique identifier of team

  • body:

    the object to pass as the request payload



3498
3499
3500
# File 'lib/platform-api/client.rb', line 3498

def create_by_team(team_name_or_team_id, body = {})
  @client.whitelisted_addon_service.create_by_team(team_name_or_team_id, body)
end

#delete_by_organization(organization_name_or_organization_id, whitelisted_addon_service_id_or_addon_service_name) ⇒ Object

Remove a whitelisted entity

Parameters:

  • organization_name_or_organization_id:

    unique name of organization or unique identifier of organization

  • whitelisted_addon_service_id_or_addon_service_name:

    unique identifier for this whitelisting entity or unique name of this add-on-service



3483
3484
3485
# File 'lib/platform-api/client.rb', line 3483

def delete_by_organization(organization_name_or_organization_id, whitelisted_addon_service_id_or_addon_service_name)
  @client.whitelisted_addon_service.delete_by_organization(organization_name_or_organization_id, whitelisted_addon_service_id_or_addon_service_name)
end

#delete_by_team(team_name_or_team_id, whitelisted_addon_service_id_or_addon_service_name) ⇒ Object

Remove a whitelisted entity

Parameters:

  • team_name_or_team_id:

    unique name of team or unique identifier of team

  • whitelisted_addon_service_id_or_addon_service_name:

    unique identifier for this whitelisting entity or unique name of this add-on-service



3506
3507
3508
# File 'lib/platform-api/client.rb', line 3506

def delete_by_team(team_name_or_team_id, whitelisted_addon_service_id_or_addon_service_name)
  @client.whitelisted_addon_service.delete_by_team(team_name_or_team_id, whitelisted_addon_service_id_or_addon_service_name)
end

#list_by_organization(organization_name_or_organization_id) ⇒ Object

List all whitelisted Add-on Services for an Organization

Parameters:

  • organization_name_or_organization_id:

    unique name of organization or unique identifier of organization



3467
3468
3469
# File 'lib/platform-api/client.rb', line 3467

def list_by_organization(organization_name_or_organization_id)
  @client.whitelisted_addon_service.list_by_organization(organization_name_or_organization_id)
end

#list_by_team(team_name_or_team_id) ⇒ Object

List all whitelisted Add-on Services for a Team

Parameters:

  • team_name_or_team_id:

    unique name of team or unique identifier of team



3490
3491
3492
# File 'lib/platform-api/client.rb', line 3490

def list_by_team(team_name_or_team_id)
  @client.whitelisted_addon_service.list_by_team(team_name_or_team_id)
end