Class: PlatformAPI::ConfigVar

Inherits:
Object
  • Object
show all
Defined in:
lib/platform-api/client.rb

Overview

Config Vars allow you to manage the configuration information provided to an app on Heroku.

Instance Method Summary collapse

Constructor Details

#initialize(client) ⇒ ConfigVar

Returns a new instance of ConfigVar.



784
785
786
# File 'lib/platform-api/client.rb', line 784

def initialize(client)
  @client = client
end

Instance Method Details

#info(app_id_or_app_name) ⇒ Object

Get config-vars for app.

Parameters:

  • app_id_or_app_name:

    unique identifier of app or unique name of app



791
792
793
# File 'lib/platform-api/client.rb', line 791

def info(app_id_or_app_name)
  @client.config_var.info(app_id_or_app_name)
end

#update(app_id_or_app_name, body) ⇒ Object

Update config-vars for app. You can update existing config-vars by setting them again, and remove by setting it to NULL.

Parameters:

  • app_id_or_app_name:

    unique identifier of app or unique name of app

  • body:

    the object to pass as the request payload



799
800
801
# File 'lib/platform-api/client.rb', line 799

def update(app_id_or_app_name, body)
  @client.config_var.update(app_id_or_app_name, body)
end