Class: PlatformAPI::Formation

Inherits:
Object
  • Object
show all
Defined in:
lib/platform-api/client.rb

Overview

The formation of processes that should be maintained for an app. Update the formation to scale processes or change dyno sizes. Available process type names and commands are defined by the process_types attribute for the slug currently released on an app.

Instance Method Summary collapse

Constructor Details

#initialize(client) ⇒ Formation

Returns a new instance of Formation.



1422
1423
1424
# File 'lib/platform-api/client.rb', line 1422

def initialize(client)
  @client = client
end

Instance Method Details

#batch_update(app_id_or_app_name, body = {}) ⇒ Object

Batch update process types

Parameters:

  • app_id_or_app_name:

    unique identifier of app or unique name of app

  • body:

    the object to pass as the request payload



1445
1446
1447
# File 'lib/platform-api/client.rb', line 1445

def batch_update(app_id_or_app_name, body = {})
  @client.formation.batch_update(app_id_or_app_name, body)
end

#info(app_id_or_app_name, formation_id_or_formation_type) ⇒ Object

Info for a process type

Parameters:

  • app_id_or_app_name:

    unique identifier of app or unique name of app

  • formation_id_or_formation_type:

    unique identifier of this process type or type of process to maintain



1430
1431
1432
# File 'lib/platform-api/client.rb', line 1430

def info(app_id_or_app_name, formation_id_or_formation_type)
  @client.formation.info(app_id_or_app_name, formation_id_or_formation_type)
end

#list(app_id_or_app_name) ⇒ Object

List process type formation

Parameters:

  • app_id_or_app_name:

    unique identifier of app or unique name of app



1437
1438
1439
# File 'lib/platform-api/client.rb', line 1437

def list(app_id_or_app_name)
  @client.formation.list(app_id_or_app_name)
end

#update(app_id_or_app_name, formation_id_or_formation_type, body = {}) ⇒ Object

Update process type

Parameters:

  • app_id_or_app_name:

    unique identifier of app or unique name of app

  • formation_id_or_formation_type:

    unique identifier of this process type or type of process to maintain

  • body:

    the object to pass as the request payload



1454
1455
1456
# File 'lib/platform-api/client.rb', line 1454

def update(app_id_or_app_name, formation_id_or_formation_type, body = {})
  @client.formation.update(app_id_or_app_name, formation_id_or_formation_type, body)
end