Class: PlatformAPI::Key
- Inherits:
-
Object
- Object
- PlatformAPI::Key
- Defined in:
- lib/platform-api/client.rb
Overview
Keys represent public SSH keys associated with an account and are used to authorize accounts as they are performing git operations.
Instance Method Summary collapse
- #info(key_id_or_key_fingerprint) ⇒ Object
-
#initialize(client) ⇒ Key
constructor
A new instance of Key.
-
#list ⇒ Object
List existing keys.
Constructor Details
#initialize(client) ⇒ Key
Returns a new instance of Key.
3050 3051 3052 |
# File 'lib/platform-api/client.rb', line 3050 def initialize(client) @client = client end |
Instance Method Details
#info(key_id_or_key_fingerprint) ⇒ Object
3062 3063 3064 |
# File 'lib/platform-api/client.rb', line 3062 def info(key_id_or_key_fingerprint) @client.key.info(key_id_or_key_fingerprint) end |
#list ⇒ Object
List existing keys.
3069 3070 3071 |
# File 'lib/platform-api/client.rb', line 3069 def list() @client.key.list() end |