Class: PlatformAPI::Organization
- Inherits:
-
Object
- Object
- PlatformAPI::Organization
- Defined in:
- lib/platform-api/client.rb
Overview
Organizations allow you to manage access to a shared group of applications across your development team.
Instance Method Summary collapse
-
#info(organization_name) ⇒ Object
Info for an organization.
-
#initialize(client) ⇒ Organization
constructor
A new instance of Organization.
-
#list ⇒ Object
List organizations in which you are a member.
-
#update(organization_name, body) ⇒ Object
Set or unset the organization as your default organization.
Constructor Details
#initialize(client) ⇒ Organization
Returns a new instance of Organization.
1334 1335 1336 |
# File 'lib/platform-api/client.rb', line 1334 def initialize(client) @client = client end |
Instance Method Details
#info(organization_name) ⇒ Object
Info for an organization.
1346 1347 1348 |
# File 'lib/platform-api/client.rb', line 1346 def info(organization_name) @client.organization.info(organization_name) end |
#list ⇒ Object
List organizations in which you are a member.
1339 1340 1341 |
# File 'lib/platform-api/client.rb', line 1339 def list() @client.organization.list() end |
#update(organization_name, body) ⇒ Object
Set or unset the organization as your default organization.
1354 1355 1356 |
# File 'lib/platform-api/client.rb', line 1354 def update(organization_name, body) @client.organization.update(organization_name, body) end |