Class: PlatformAPI::PipelineStack
- Inherits:
-
Object
- Object
- PlatformAPI::PipelineStack
- Defined in:
- lib/platform-api/client.rb
Overview
A pipeline's stack is determined by the apps in the pipeline. This is used during creation of CI and Review Apps that have no stack defined in app.json
Instance Method Summary collapse
- #default_stack(pipeline_id) ⇒ Object
-
#initialize(client) ⇒ PipelineStack
constructor
A new instance of PipelineStack.
Constructor Details
#initialize(client) ⇒ PipelineStack
Returns a new instance of PipelineStack.
3832 3833 3834 |
# File 'lib/platform-api/client.rb', line 3832 def initialize(client) @client = client end |
Instance Method Details
#default_stack(pipeline_id) ⇒ Object
3844 3845 3846 |
# File 'lib/platform-api/client.rb', line 3844 def default_stack(pipeline_id) @client.pipeline_stack.default_stack(pipeline_id) end |