Class: PlatformAPI::Slug
- Inherits:
-
Object
- Object
- PlatformAPI::Slug
- Defined in:
- lib/platform-api/client.rb
Overview
A slug is a snapshot of your application code that is ready to run on the platform.
Instance Method Summary collapse
- #create(app_id_or_app_name, body = {}) ⇒ Object
- #info(app_id_or_app_name, slug_id) ⇒ Object
-
#initialize(client) ⇒ Slug
constructor
A new instance of Slug.
Constructor Details
#initialize(client) ⇒ Slug
Returns a new instance of Slug.
4224 4225 4226 |
# File 'lib/platform-api/client.rb', line 4224 def initialize(client) @client = client end |
Instance Method Details
#create(app_id_or_app_name, body = {}) ⇒ Object
4252 4253 4254 |
# File 'lib/platform-api/client.rb', line 4252 def create(app_id_or_app_name, body = {}) @client.slug.create(app_id_or_app_name, body) end |
#info(app_id_or_app_name, slug_id) ⇒ Object
4238 4239 4240 |
# File 'lib/platform-api/client.rb', line 4238 def info(app_id_or_app_name, slug_id) @client.slug.info(app_id_or_app_name, slug_id) end |