Class: PlatformAPI::WhitelistedAddonService

Inherits:
Object
  • Object
show all
Defined in:
lib/platform-api/client.rb

Overview

Entities that have been whitelisted to be used by an Organization

Instance Method Summary collapse

Constructor Details

#initialize(client) ⇒ WhitelistedAddonService

Returns a new instance of WhitelistedAddonService.



3084
3085
3086
# File 'lib/platform-api/client.rb', line 3084

def initialize(client)
  @client = client
end

Instance Method Details

#create_by_organization(organization_name_or_organization_id, body = {}) ⇒ Object

Whitelist an Add-on Service

Parameters:

  • organization_name_or_organization_id:

    unique name of organization or unique identifier of organization

  • body:

    the object to pass as the request payload



3099
3100
3101
# File 'lib/platform-api/client.rb', line 3099

def create_by_organization(organization_name_or_organization_id, body = {})
  @client.whitelisted_addon_service.create_by_organization(organization_name_or_organization_id, body)
end

#create_by_team(team_name_or_team_id, body = {}) ⇒ Object

Whitelist an Add-on Service

Parameters:

  • team_name_or_team_id:

    unique name of team or unique identifier of team

  • body:

    the object to pass as the request payload



3122
3123
3124
# File 'lib/platform-api/client.rb', line 3122

def create_by_team(team_name_or_team_id, body = {})
  @client.whitelisted_addon_service.create_by_team(team_name_or_team_id, body)
end

#delete_by_organization(organization_name_or_organization_id, whitelisted_addon_service_id_or_addon_service_name) ⇒ Object

Remove a whitelisted entity

Parameters:

  • organization_name_or_organization_id:

    unique name of organization or unique identifier of organization

  • whitelisted_addon_service_id_or_addon_service_name:

    unique identifier for this whitelisting entity or unique name of this add-on-service



3107
3108
3109
# File 'lib/platform-api/client.rb', line 3107

def delete_by_organization(organization_name_or_organization_id, whitelisted_addon_service_id_or_addon_service_name)
  @client.whitelisted_addon_service.delete_by_organization(organization_name_or_organization_id, whitelisted_addon_service_id_or_addon_service_name)
end

#delete_by_team(team_name_or_team_id, whitelisted_addon_service_id_or_addon_service_name) ⇒ Object

Remove a whitelisted entity

Parameters:

  • team_name_or_team_id:

    unique name of team or unique identifier of team

  • whitelisted_addon_service_id_or_addon_service_name:

    unique identifier for this whitelisting entity or unique name of this add-on-service



3130
3131
3132
# File 'lib/platform-api/client.rb', line 3130

def delete_by_team(team_name_or_team_id, whitelisted_addon_service_id_or_addon_service_name)
  @client.whitelisted_addon_service.delete_by_team(team_name_or_team_id, whitelisted_addon_service_id_or_addon_service_name)
end

#list_by_organization(organization_name_or_organization_id) ⇒ Object

List all whitelisted Add-on Services for an Organization

Parameters:

  • organization_name_or_organization_id:

    unique name of organization or unique identifier of organization



3091
3092
3093
# File 'lib/platform-api/client.rb', line 3091

def list_by_organization(organization_name_or_organization_id)
  @client.whitelisted_addon_service.list_by_organization(organization_name_or_organization_id)
end

#list_by_team(team_name_or_team_id) ⇒ Object

List all whitelisted Add-on Services for a Team

Parameters:

  • team_name_or_team_id:

    unique name of team or unique identifier of team



3114
3115
3116
# File 'lib/platform-api/client.rb', line 3114

def list_by_team(team_name_or_team_id)
  @client.whitelisted_addon_service.list_by_team(team_name_or_team_id)
end